@@ -353,7 +353,6 @@ class Context(djvu.decode.Context):
     def handle_message(self, message):
         if isinstance(message, djvu.decode.ErrorMessage):
             logger.warning(message)
-        return djvu.decode.Context.handle_message(self, message)
 
     @contextlib.contextmanager
     def get_output_image(self, nth, page_job):
@@ -542,6 +541,7 @@ def main(argv=sys.argv):
         context.process(options.path, options.pages)
     except KeyboardInterrupt:
         logger.info('Interrupted by user.')
+        sys.exit(1)
     finally:
         temp_dir = context.close()
         if temp_dir is not None:
