@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,14 @@ from ocrodjvu.cli import djvu2hocr
 from ocrodjvu import temporary
 from ocrodjvu import ipc
 
-from tests.common import *
+from tests.common import (
+    assert_equal,
+    assert_ml_equal,
+    assert_not_equal,
+    interim,
+    sorted_glob,
+    try_run,
+)
 
 here = os.path.dirname(__file__)
 try:
